==> qtjambi-multimedia-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiMultimedia/QAudioSink_shell.h <==
#ifndef QAUDIOSINK_SHELL_H
#define QAUDIOSINK_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtMultimedia/qaudiosink.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAudioSink_shell : public QAudioSink, public QtJambiShellInterface
{
public:
    QAudioSink_shell(const QAudioDevice& audioDeviceInfo0, const QAudioFormat& format1 = QAudioFormat(), QObject* parent2 = nullptr);
    QAudioSink_shell(const QAudioFormat& format0 = QAudioFormat(), QObject* parent1 = nullptr);
    ~QAudioSink_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioSink_access : public QAudioSink
{
};

#endif // QAUDIOSINK_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QAudioSink_shell.h <==
#ifndef QAUDIOSINK_SHELL_H
#define QAUDIOSINK_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiosink.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAudioSink_shell : public QAudioSink, public QtJambiShellInterface
{
public:
    QAudioSink_shell(const QAudioDevice& audioDeviceInfo0, const QAudioFormat& format1 = QAudioFormat(), QObject* parent2 = nullptr);
    QAudioSink_shell(const QAudioFormat& format0 = QAudioFormat(), QObject* parent1 = nullptr);
    ~QAudioSink_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAudioSink_mshell;
    friend class QAudioSink_oshell;
};


class QAudioSink_mshell : public QAudioSink_shell
{
public:
    using QAudioSink_shell::QAudioSink_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAudioSink_oshell : public QAudioSink_mshell
{
public:
    using QAudioSink_mshell::QAudioSink_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioSink_access : public QAudioSink
{
};

#endif // QAUDIOSINK_SHELL_H
